@@ -1071,4 +1071,11 @@ print.summary.LNRT <- function(x, ...)
   }
   cat("\n\n")
    
+}
+
+#' @method print summary.LNIRTQ
+#' @export
+print.summary.LNIRTQ <- function(x, ...)
+{
+  summaryIRTQ(out = x$object)
 }
\ No newline at end of file
